
.. include:: README.rst

.. toctree::
   :caption: Contents
   :maxdepth: 2

   quickstart.rst
   data/image.rst
   data/subject.rst
   data/dataset.rst
   data/patch_based.rst
   transforms/transforms.rst
   datasets.rst
   cli.rst
   slicer.rst


See also
********

* `PyTorch implementation of 2D and 3D HighResNet <https://www.github.com/fepegar/highresnet>`_
* `PyTorch implementation of 2D and 3D U-Net <https://www.github.com/fepegar/unet>`_
